import { csv, select } from 'd3';
import { scatterPlot } from './scatterPlot';

const csvUrl = [
  'https://gist.githubusercontent.com/',
  'Bhanuteja-1807/', // User
  '47ea186e014af26548aff97c8eb9ad4f/', // Id of the Gist
  'raw/cff7f9d8e11fd74f51fa5074938ad274cb8389ee/', // commit
  'Iris.csv', // File name
].join('');
const parseRow = (d) => {
  d.SepalLengthCm = +d.SepalLengthCm;
  d.SepalWidthCm = +d.SepalWidthCm;
  d.PetalLengthCm = +d.PetalLengthCm;
  d.PetalWidthCm = +d.PetalWidthCm;
  return d;
};

const width = window.innerWidth;
const height = window.innerHeight;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const main = async () => {
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.PetalWidthCm)
    .yValue((d) => d.SepalLengthCm)
    .margin({
      top: 20,
      right: 20,
      bottom: 40,
      left: 50,
    })
    .radius(5);

  svg.call(plot);

  const columns = [
    'PetalWidthCm',
    'SepalWidthCm',
    'PetalLengthCm',
    'SepalLengthCm',
  ];
  let i = 0;
  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]);
    svg.call(plot);
    i++;
  }, 2000);
};
main();



